==> optimum_rbln-0.8.2a2.tar.gz: optimum_rbln-0.8.2a2/src/optimum/rbln/transformers/models/siglip/configuration_siglip.py <==
# Copyright 2025 Rebellions Inc. All rights reserved.

# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at:

#     http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from typing import Optional

from ....configuration_utils import RBLNModelConfig


class RBLNSiglipVisionModelConfig(RBLNModelConfig):
    """
    Configuration class for RBLNSiglipVisionModel.

    This configuration class stores the configuration parameters specific to
    RBLN-optimized SigLIP vision models for image encoding in multimodal tasks.
    """

    def __init__(
        self,
        batch_size: Optional[int] = None,
        image_size: Optional[int] = None,
        interpolate_pos_encoding: Optional[bool] = None,
        output_hidden_states: Optional[bool] = None,
        output_attentions: Optional[bool] = None,
        **kwargs,
    ):
        """
        Args:
            batch_size (Optional[int]): The batch size for image processing. Defaults to 1.
            image_size (Optional[int]): The size of input images. Can be an integer for square images,
                a tuple/list (height, width), or a dictionary with 'height' and 'width' keys.
            interpolate_pos_encoding (Optional[bool]): Whether to interpolate the position encoding.
            output_hidden_states: (Optional[bool]): Whether to return hidden states.
            output_attentions: (Optional[bool]): Whether to return attentions.
            **kwargs: Additional arguments passed to the parent RBLNModelConfig.

        Raises:
            ValueError: If batch_size is not a positive integer.
        """
        super().__init__(**kwargs)
        self.batch_size = batch_size or 1
        if not isinstance(self.batch_size, int) or self.batch_size < 0:
            raise ValueError(f"batch_size must be a positive integer, got {self.batch_size}")

        self.image_size = image_size
        self.interpolate_pos_encoding = interpolate_pos_encoding or False
        self.output_hidden_states = output_hidden_states
        self.output_attentions = output_attentions

    @property
    def image_width(self):
        if isinstance(self.image_size, int):
            return self.image_size
        elif isinstance(self.image_size, (list, tuple)):
            return self.image_size[1]
        else:
            return self.image_size["width"]

    @property
    def image_height(self):
        if isinstance(self.image_size, int):
            return self.image_size
        elif isinstance(self.image_size, (list, tuple)):
            return self.image_size[0]
        else:
            return self.image_size["height"]

==> optimum_rbln-0.9.2a3.tar.gz: optimum_rbln-0.9.2a3/src/optimum/rbln/transformers/models/siglip/configuration_siglip.py <==
# Copyright 2025 Rebellions Inc. All rights reserved.

# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at:

#     http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from typing import Optional

from ....configuration_utils import RBLNModelConfig


class RBLNSiglipVisionModelConfig(RBLNModelConfig):
    """
    Configuration class for RBLNSiglipVisionModel.

    This configuration class stores the configuration parameters specific to
    RBLN-optimized SigLIP vision models for image encoding in multimodal tasks.
    """

    def __init__(
        self,
        batch_size: Optional[int] = None,
        image_size: Optional[int] = None,
        interpolate_pos_encoding: Optional[bool] = None,
        output_hidden_states: Optional[bool] = None,
        output_attentions: Optional[bool] = None,
        **kwargs,
    ):
        """
        Args:
            batch_size (Optional[int]): The batch size for image processing. Defaults to 1.
            image_size (Optional[int]): The size of input images. Can be an integer for square images,
                a tuple/list (height, width), or a dictionary with 'height' and 'width' keys.
            interpolate_pos_encoding (Optional[bool]): Whether to interpolate the position encoding.
            output_hidden_states: (Optional[bool]): Whether to return hidden states.
            output_attentions: (Optional[bool]): Whether to return attentions.
            kwargs: Additional arguments passed to the parent RBLNModelConfig.

        Raises:
            ValueError: If batch_size is not a positive integer.
        """
        super().__init__(**kwargs)
        self.batch_size = batch_size or 1
        if not isinstance(self.batch_size, int) or self.batch_size < 0:
            raise ValueError(f"batch_size must be a positive integer, got {self.batch_size}")

        self.image_size = image_size
        self.interpolate_pos_encoding = interpolate_pos_encoding or False
        self.output_hidden_states = output_hidden_states
        self.output_attentions = output_attentions

    @property
    def image_width(self):
        if isinstance(self.image_size, int):
            return self.image_size
        elif isinstance(self.image_size, (list, tuple)):
            return self.image_size[1]
        else:
            return self.image_size["width"]

    @property
    def image_height(self):
        if isinstance(self.image_size, int):
            return self.image_size
        elif isinstance(self.image_size, (list, tuple)):
            return self.image_size[0]
        else:
            return self.image_size["height"]
